Learn R Programming

weatherindices (version 0.1.0)

Burdwanriceyield: Yearly Yield data of rice in Burdwan district of West Bengal, India over 39 years

Description

Contains the Years and yield data in Tonnes per hectare

Usage

Burdwanriceyield

Arguments

Format

A data frame with 39 rows of 2 variables

Year

starting year of data

burdwan

rice yield data of burdwan district

Examples

Run this code
data(Burdwanriceyield)

Run the code above in your browser using DataLab