Learn R Programming

weatherindices (version 0.1.0)

i.wwi: Weighted Interaction Weather Indices

Description

Converts the weekly interaction of two weather variable into yearly weighted interaction weather indices with weights being the correlation coefficient between weekly weather data over the years and crop yield over the years

Usage

i.wwi(y, weatherp1, weatherp2)

Value

A vector of interaction weather indices

Arguments

y

A vector of yearly yield data for t years

weatherp1

Weekly weather data for t years as vector for first weather variable(total observations= number of years*number of weeks in each year)

weatherp2

Weekly weather data for t years as vector for second weather variable(total observations= number of years*number of weeks in each year)

References

Jain, R. C., Agrawal, R., & Jha, M. P. (1980). Effect of climatic variables on rice yield and its forecast. MAUSAM, 31(4), 591-596.

Examples

Run this code
data(Burdwanweather) #Weekly weather data for the rice growing season in Burdwan
data(Burdwanriceyield) #Yearly Yield data of rice  in Burdwan
i.wwi.maxmintem<-i.wwi(Burdwanriceyield$burdwan,Burdwanweather$Max.Temperature,
                       Burdwanweather$Min.Temperature)
i.wwi.maxmintem

Run the code above in your browser using DataLab